@@ -2,11 +2,16 @@
 configuration from different file formats.
 """
 
-
-from .config import BadConfigException, ConfigLoader, MissingConfigException
+from .abstract_config import (
+    AbstractConfigLoader,
+    BadConfigException,
+    MissingConfigException,
+)
+from .config import ConfigLoader
 from .templated_config import TemplatedConfigLoader
 
 __all__ = [
+    "AbstractConfigLoader",
     "BadConfigException",
     "ConfigLoader",
     "MissingConfigException",
