@@ -10,10 +10,7 @@ from pathlib import Path
 from typing import Sequence
 
 import click
-import pkg_resources
 
-# pylint: disable=unused-import
-import kedro.config.default_logger  # noqa
 from kedro import __version__ as version
 from kedro.framework.cli.catalog import catalog_cli
 from kedro.framework.cli.hooks import get_cli_hook_manager
@@ -28,8 +25,10 @@ from kedro.framework.cli.utils import (
     ENTRY_POINT_GROUPS,
     CommandCollection,
     KedroCliError,
+    _get_entry_points,
     load_entry_points,
 )
+from kedro.framework.project import LOGGING  # noqa # pylint:disable=unused-import
 from kedro.framework.startup import _is_project, bootstrap_project
 
 LOGO = rf"""
@@ -64,11 +63,10 @@ def info():
 
     plugin_versions = {}
     plugin_entry_points = defaultdict(set)
-    for plugin_entry_point, group in ENTRY_POINT_GROUPS.items():
-        for entry_point in pkg_resources.iter_entry_points(group=group):
-            module_name = entry_point.module_name.split(".")[0]
-            plugin_version = pkg_resources.get_distribution(module_name).version
-            plugin_versions[module_name] = plugin_version
+    for plugin_entry_point in ENTRY_POINT_GROUPS:
+        for entry_point in _get_entry_points(plugin_entry_point):
+            module_name = entry_point.module.split(".")[0]
+            plugin_versions[module_name] = entry_point.dist.version
             plugin_entry_points[module_name].add(plugin_entry_point)
 
     click.echo()
@@ -87,7 +85,7 @@ def info():
 def docs():
     """Display the online API docs and introductory tutorial in the browser. (DEPRECATED)"""
     deprecation_message = (
-        "DeprecationWarning: Command `kedro docs` is deprecated and "
+        "DeprecationWarning: Command 'kedro docs' is deprecated and "
         "will not be available from Kedro 0.19.0."
     )
     click.secho(deprecation_message, fg="red")
@@ -96,14 +94,10 @@ def docs():
     webbrowser.open(index_path)
 
 
-def _init_plugins():
-    group = ENTRY_POINT_GROUPS["init"]
-    for entry_point in pkg_resources.iter_entry_points(group=group):
-        try:
-            init_hook = entry_point.load()
-            init_hook()
-        except Exception as exc:
-            raise KedroCliError(f"Initializing {entry_point}") from exc
+def _init_plugins() -> None:
+    init_hooks = load_entry_points("init")
+    for init_hook in init_hooks:
+        init_hook()
 
 
 class KedroCLI(CommandCollection):
