@@ -29,7 +29,7 @@ from kedro.framework.startup import ProjectMetadata
 from kedro.utils import load_obj
 
 NO_DEPENDENCY_MESSAGE = """{module} is not installed. Please make sure {module} is in
-{src}/requirements.txt and run `pip install -r src/requirements.txt`."""
+{src}/requirements.txt and run 'pip install -r src/requirements.txt'."""
 LINT_CHECK_ONLY_HELP = """Check the files for style guide violations, unsorted /
 unformatted imports, and unblackened Python code without modifying the files."""
 OPEN_ARG_HELP = """Open the documentation in your default browser after building."""
@@ -41,7 +41,7 @@ FROM_NODES_HELP = """A list of node names which should be used as a starting poi
 TO_NODES_HELP = """A list of node names which should be used as an end point."""
 NODE_ARG_HELP = """Run only nodes with specified names."""
 RUNNER_ARG_HELP = """Specify a runner that you want to run the pipeline with.
-Available runners: `SequentialRunner`, `ParallelRunner` and `ThreadRunner`."""
+Available runners: 'SequentialRunner', 'ParallelRunner' and 'ThreadRun'."""
 ASYNC_ARG_HELP = """Load and save node inputs and outputs asynchronously
 with threads. If not specified, load and save datasets synchronously."""
 TAG_ARG_HELP = """Construct the pipeline using only nodes which have this tag
@@ -235,7 +235,7 @@ def build_reqs(
 
     else:
         raise FileNotFoundError(
-            f"File `{input_file}` not found in the project. "
+            f"File '{input_file}' not found in the project. "
             "Please specify another input or create the file and try again."
         )
 
@@ -276,7 +276,7 @@ def activate_nbstripout(
             stderr=subprocess.PIPE,
         )
         if res.returncode:
-            raise KedroCliError("Not a git repository. Run `git init` first.")
+            raise KedroCliError("Not a git repository. Run 'git init' first.")
     except FileNotFoundError as exc:
         raise KedroCliError("Git executable not found. Install Git first.") from exc
 
