@@ -4,9 +4,16 @@ configure a Kedro project and access its settings."""
 import importlib
 import logging.config
 import operator
+import sys
+from collections import UserDict
 from collections.abc import MutableMapping
+from pathlib import Path
 from typing import Any, Dict, Optional
 
+import click
+import rich.pretty
+import rich.traceback
+import yaml
 from dynaconf import LazySettings
 from dynaconf.validator import ValidationError, Validator
 
@@ -33,9 +40,9 @@ class _IsSubclassValidator(Validator):
             setting_value = getattr(settings, name)
             if not issubclass(setting_value, default_class):
                 raise ValidationError(
-                    f"Invalid value `{setting_value.__module__}.{setting_value.__qualname__}` "
-                    f"received for setting `{name}`. It must be a subclass of "
-                    f"`{default_class.__module__}.{default_class.__qualname__}`."
+                    f"Invalid value '{setting_value.__module__}.{setting_value.__qualname__}' "
+                    f"received for setting '{name}'. It must be a subclass of "
+                    f"'{default_class.__module__}.{default_class.__qualname__}'."
                 )
 
 
@@ -62,9 +69,9 @@ class _HasSharedParentClassValidator(Validator):
             default_class_parent = default_class.mro()[1]
             if default_class_parent not in setting_value.mro():
                 raise ValidationError(
-                    f"Invalid value `{setting_value.__module__}.{setting_value.__qualname__}` "
-                    f"received for setting `{name}`. It must be a subclass of "
-                    f"`{default_class_parent.__module__}.{default_class_parent.__qualname__}`."
+                    f"Invalid value '{setting_value.__module__}.{setting_value.__qualname__}' "
+                    f"received for setting '{name}'. It must be a subclass of "
+                    f"'{default_class_parent.__module__}.{default_class_parent.__qualname__}'."
                 )
 
 
@@ -179,8 +186,36 @@ class _ProjectPipelines(MutableMapping):
     __str__ = _load_data_wrapper(str)
 
 
+class _ProjectLogging(UserDict):
+    # pylint: disable=super-init-not-called
+    def __init__(self):
+        """Initialise project logging with default configuration. Also enable
+        rich tracebacks."""
+        default_logging = (Path(__file__).parent / "default_logging.yml").read_text(
+            encoding="utf-8"
+        )
+        self.configure(yaml.safe_load(default_logging))
+        logging.captureWarnings(True)
+
+        # We suppress click here to hide tracebacks related to it conversely,
+        # kedro is not suppressed to show its tracebacks for easier debugging.
+        # sys.executable is used to get the kedro executable path to hide the top level traceback.
+        rich.traceback.install(
+            show_locals=True, suppress=[click, str(Path(sys.executable).parent)]
+        )
+        rich.pretty.install()
+
+    def configure(self, logging_config: Dict[str, Any]) -> None:
+        """Configure project logging using `logging_config` (e.g. from project
+        logging.yml). We store this in the UserDict data so that it can be reconfigured
+        in _bootstrap_subprocess.
+        """
+        logging.config.dictConfig(logging_config)
+        self.data = logging_config
+
+
 PACKAGE_NAME = None
-LOGGING = None
+LOGGING = _ProjectLogging()
 
 settings = _ProjectSettings()
 
@@ -206,10 +241,8 @@ def configure_project(package_name: str):
 
 
 def configure_logging(logging_config: Dict[str, Any]) -> None:
-    """Configure logging to make it available as a global variable."""
-    logging.config.dictConfig(logging_config)
-    global LOGGING
-    LOGGING = logging_config
+    """Configure logging according to `logging_config` dictionary."""
+    LOGGING.configure(logging_config)
 
 
 def validate_settings():
