@@ -1,6 +1,6 @@
 """``kedro.framework.session`` provides access to KedroSession responsible for
 project lifecycle.
 """
-from .session import KedroSession, get_current_session
+from .session import KedroSession
 
-__all__ = ["KedroSession", "get_current_session"]
+__all__ = ["KedroSession"]
