@@ -1,4 +1,3 @@
-# pylint: disable=invalid-name,global-statement
 """This module implements Kedro session responsible for project lifecycle."""
 import getpass
 import logging
@@ -13,7 +12,7 @@ from typing import Any, Dict, Iterable, Union
 import click
 
 from kedro import __version__ as kedro_version
-from kedro.config import ConfigLoader
+from kedro.config import ConfigLoader, MissingConfigException
 from kedro.framework.context import KedroContext
 from kedro.framework.context.context import _convert_paths_to_absolute_posix
 from kedro.framework.hooks import _create_hook_manager
@@ -47,7 +46,7 @@ def _describe_git(project_path: Path) -> Dict[str, Dict[str, Any]]:
 
     # `subprocess.check_output()` raises `NotADirectoryError` on Windows
     except (subprocess.CalledProcessError, FileNotFoundError, NotADirectoryError):
-        logging.getLogger(__name__).warning("Unable to git describe %s", project_path)
+        logging.getLogger(__name__).debug("Unable to git describe %s", project_path)
         return {}
 
     return {"git": git_data}
@@ -164,7 +163,12 @@ class KedroSession:
         if extra_params:
             session_data["extra_params"] = extra_params
 
-        session_data["username"] = getpass.getuser()
+        try:
+            session_data["username"] = getpass.getuser()
+        except Exception as exc:  # pylint: disable=broad-except
+            logging.getLogger(__name__).debug(
+                "Unable to get username. Full exception: %s", exc
+            )
 
         session._store.update(session_data)
 
@@ -173,20 +177,27 @@ class KedroSession:
         return session
 
     def _get_logging_config(self) -> Dict[str, Any]:
-        conf_logging = self._get_config_loader().get(
+        logging_config = self._get_config_loader().get(
             "logging*", "logging*/**", "**/logging*"
         )
         # turn relative paths in logging config into absolute path
         # before initialising loggers
-        conf_logging = _convert_paths_to_absolute_posix(
-            project_path=self._project_path, conf_dictionary=conf_logging
+        logging_config = _convert_paths_to_absolute_posix(
+            project_path=self._project_path, conf_dictionary=logging_config
         )
-        return conf_logging
+        return logging_config
 
     def _setup_logging(self) -> None:
         """Register logging specified in logging directory."""
-        conf_logging = self._get_logging_config()
-        configure_logging(conf_logging)
+        try:
+            logging_config = self._get_logging_config()
+        except MissingConfigException:
+            self._logger.debug(
+                "No project logging configuration loaded; "
+                "Kedro's default logging configuration will be used."
+            )
+        else:
+            configure_logging(logging_config)
 
     def _init_store(self) -> BaseSessionStore:
         store_class = settings.SESSION_STORE_CLASS
@@ -200,11 +211,11 @@ class KedroSession:
         except TypeError as err:
             raise ValueError(
                 f"\n{err}.\nStore config must only contain arguments valid "
-                f"for the constructor of `{classpath}`."
+                f"for the constructor of '{classpath}'."
             ) from err
         except Exception as err:
             raise ValueError(
-                f"\n{err}.\nFailed to instantiate session store of type `{classpath}`."
+                f"\n{err}.\nFailed to instantiate session store of type '{classpath}'."
             ) from err
 
     def _log_exception(self, exc_type, exc_value, exc_tb):
@@ -324,7 +335,7 @@ class KedroSession:
         """
         # pylint: disable=protected-access,no-member
         # Report project name
-        self._logger.info("** Kedro project %s", self._project_path.name)
+        self._logger.info("Kedro project %s", self._project_path.name)
 
         if self._run_called:
             raise KedroSessionError(
