@@ -39,9 +39,9 @@ class ThreadRunner(AbstractRunner):
         """
         if is_async:
             warnings.warn(
-                "`ThreadRunner` doesn't support loading and saving the "
+                "'ThreadRunner' doesn't support loading and saving the "
                 "node inputs and outputs asynchronously with threads. "
-                "Setting `is_async` to False."
+                "Setting 'is_async' to False."
             )
         super().__init__(is_async=False)
 
@@ -92,6 +92,7 @@ class ThreadRunner(AbstractRunner):
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
+            hook_manager: The ``PluginManager`` to activate hooks.
             session_id: The id of the session.
 
         Raises:
